use crate::helpers::jwt::get_token;
use crate::middlewares::error::ErrorResponse;
use crate::models::user::Users;
use actix_web::http::{header, StatusCode};
use actix_web::HttpRequest;

pub fn get_user(req: HttpRequest) -> Result<Users, ErrorResponse> {
    let authorization = req.headers().get(header::AUTHORIZATION);

    match authorization {
        Some(header) => {
            let claims = get_token(header.to_str().unwrap());

            match claims {
                Ok(claims) => {
                    let user = Users::find(claims["user_id"].as_str())?;

                    Ok(user)
                }
                Err(e) => {
                    return Err(ErrorResponse {
                        message: e.to_string(),
                        status: StatusCode::INTERNAL_SERVER_ERROR,
                    })
                }
            }
        }
        None => {
            return Err(ErrorResponse {
                message: "Not Authorized".to_string(),
                status: StatusCode::UNAUTHORIZED,
            });
        }
    }
}
