use crate::middlewares::error::ErrorResponse;
use crate::models::user::Users;
use crate::utils::get_jwt_secret;
use actix_web::http::StatusCode;
use actix_web::{post, web, HttpResponse};
use jwt::SignWithKey;
use serde::{Deserialize, Serialize};
use std::collections::BTreeMap;

#[post("/auth/login")]
async fn login(body: web::Json<LoginBody>) -> Result<HttpResponse, ErrorResponse> {
    #[derive(Deserialize, Serialize)]
    struct Response {
        access_token: String,
    }

    let user = Users::find_by_email(&body.email);
    match user {
        Ok(user) => {
            let password = Users::verify_password(&body.password, &user);

            if password == false {
                return Err(ErrorResponse {
                    message: "Invalid credentials.".to_string(),
                    status: StatusCode::BAD_REQUEST,
                });
            }

            let key = get_jwt_secret().unwrap();
            let mut claims = BTreeMap::new();
            claims.insert("user_id", &user.id);
            let token_str = claims.sign_with_key(&key).unwrap();

            Ok(HttpResponse::Ok().json(Response {
                access_token: token_str,
            }))
        }
        Err(_err) => {
            return Err(ErrorResponse {
                message: "Invalid credentials.".to_string(),
                status: StatusCode::BAD_REQUEST,
            })
        }
    }
}

#[derive(Deserialize)]
struct LoginBody {
    email: String,
    password: String,
}
