use crate::middlewares::error::ErrorResponse;
use crate::models::playlist::{PlaylistCreator, Playlists};
use crate::models::tracks::Tracks;
use actix_web::{get, web, HttpResponse};
use serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize)]
struct GetPlaylistResponse {
    pub id: String,
    pub name: String,
    pub creator: PlaylistCreator,
    pub tracks: Vec<Tracks>,
}

#[get("/{playlist_id}")]
pub async fn get_playlist(path: web::Path<String>) -> Result<HttpResponse, ErrorResponse> {
    let playlist_id = path.into_inner();
    let playlist = Playlists::find(playlist_id.as_str())?;

    let creator = playlist.get_creator()?;

    Ok(HttpResponse::Ok().json(GetPlaylistResponse {
        id: playlist.id.to_string(),
        name: playlist.name.to_string(),
        creator: PlaylistCreator {
            id: creator.id,
            name: creator.name,
        },
        tracks: playlist.get_tracks()?,
    }))
}
