use crate::middlewares::error::ErrorResponse;
use crate::models::user::Users;
use actix_web::http::StatusCode;
use actix_web::{get, web, HttpResponse, Result};
use diesel::result::Error as DBError;
use serde::Serialize;

#[derive(Serialize)]
struct GetUserResponse {
    id: String,
    name: String,
}

#[get("/{user_id}")]
async fn get_user(path: web::Path<String>) -> Result<HttpResponse, ErrorResponse> {
    let user_id = path.into_inner();

    let user = Users::find(user_id.as_str());

    match user {
        Ok(user) => Ok(HttpResponse::Ok().json(GetUserResponse {
            id: user.id,
            name: user.name,
        })),
        Err(DBError::NotFound) => {
            return Err(ErrorResponse {
                message: "User not found".to_string(),
                status: StatusCode::NOT_FOUND,
            })
        }
        _ => {
            return Err(ErrorResponse {
                message: "Unknown error".to_string(),
                status: StatusCode::INTERNAL_SERVER_ERROR,
            })
        }
    }
}
